@@ -88,6 +88,7 @@ def main():
             "the file can have is the token, optionally with a trailing new line." )
 
     argumentParser.add_argument( "-mr", "--maximum-repositories", action="store", type=int, default=0,
+            metavar="number",
             help="The maximum count of repositories/requests to process per file." )
 
     argumentParser.add_argument( "-c", "--cancel-operation", action="store_true", default=False,
@@ -103,13 +104,13 @@ def main():
             "because to compute correctly the repositories list, it is required to know all "
             "available repositories." )
 
-    argumentParser.add_argument( "-ei", "--enable-issues", action="store", default="",
+    argumentParser.add_argument( "-ei", "--enable-issues", action="store", default="", metavar="targetusername",
             help="Enable the issue tracker on all repositories for the given user." )
 
-    argumentParser.add_argument( "-as", "--add-stars", action="store", default="",
+    argumentParser.add_argument( "-as", "--add-stars", action="store", default="", metavar="targetusername",
             help="Add a star on all repositories for the given user." )
 
-    argumentParser.add_argument( "-wa", "--watch-all", action="store", default="",
+    argumentParser.add_argument( "-wa", "--watch-all", action="store", default="", metavar="targetusername",
             help="Enable watch for all repositories on the given user." )
 
     argumentsNamespace = argumentParser.parse_args()
@@ -359,6 +360,12 @@ class PullRequester(object):
                             False
                         )
 
+                # avoid new rate limit:
+                # You have exceeded a secondary rate limit and have been temporarily blocked
+                # from content creation. Please retry your request again later.', 'documentation_url':
+                # 'https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits
+                time.sleep(3)
+
                 # Then play with your Github objects
                 successful_resquests += 1
                 log( 1, 'Successfully Created:', fork_pullrequest )
@@ -529,7 +536,7 @@ def is_allowed_to_run():
 
 
 def enable_github_issue_tracker(username):
-    def add_star(index, repository_id):
+    def graphql(index, repository_id):
         return wrap_text( """
             update%05d: updateRepository(input:{repositoryId:"%s", hasIssuesEnabled:true}) {
               repository {
@@ -537,11 +544,11 @@ def enable_github_issue_tracker(username):
               }
             }
         """ % ( index, repository_id ) )
-    run_action_on_all_repositories(username, add_star)
+    run_action_on_all_repositories(username, graphql)
 
 
 def add_stars_on_github_repositories(username):
-    def add_star(index, repository_id):
+    def graphql(index, repository_id):
         return wrap_text( """
             update%05d: addStar(input:{starrableId:"%s"}) {
               clientMutationId
@@ -550,11 +557,11 @@ def add_stars_on_github_repositories(username):
               }
             }
         """ % ( index, repository_id ) )
-    run_action_on_all_repositories(username, add_star)
+    run_action_on_all_repositories(username, graphql)
 
 
 def watch_all_github_repositories(username):
-    def add_star(index, repository_id):
+    def graphql(index, repository_id):
         return wrap_text( """
             update%05d: updateSubscription(input:{subscribableId:"%s", state:SUBSCRIBED}) {
               clientMutationId
@@ -563,7 +570,7 @@ def watch_all_github_repositories(username):
               }
             }
         """ % ( index, repository_id ) )
-    run_action_on_all_repositories(username, add_star)
+    run_action_on_all_repositories(username, graphql)
 
 
 def run_action_on_all_repositories(username, action):
@@ -579,13 +586,13 @@ def run_action_on_all_repositories(username, action):
         repositories = get_all_user_repositories(queryvariables)
 
         # log('repositories', repositories)
-        _enable_github_issue_tracker(repositories, action)
+        _run_graphql_action(repositories, action)
 
         if not queryvariables['hasNextPage']: break
         time.sleep(3)
 
 
-def _enable_github_issue_tracker(repositories, action):
+def _run_graphql_action(repositories, action):
     graphqlquery = ""
 
     for index, repository in enumerate(repositories, start=1):
